@@ -15,7 +15,7 @@
 """
 # in the module but are exported as public interface.
 
-from .adminlite import AdminClient,AdminServer,run_daemon
+from .adminlite import AdminClient,AdminServer
 from .tools import Tools
 from .commengine import CommEngineTCP,CommEngine
 
