@@ -19,6 +19,7 @@ import logging
 import os
 import time
 
+
 import yaml
 
 
@@ -149,7 +150,72 @@ class Tools(object):
         return
 
     @staticmethod
-    def parser_argument():
+    def set_debug(debug_level=logging.INFO, filename="",filter=lambda record:True):
+        '''
+        set debug mode
+
+        Args:
+            debug_level (_type_, optional): _description_. Defaults to logging.INFO.
+            filename (str, optional): if no filename will debug info on console. Defaults to "".
+            filter (_type_, optional): a lambda function . Defaults to lambdarecord:True.
+        '''
+        console = logging.StreamHandler()
+        console_filter = logging.Filter()
+        console_filter.filter = filter
+        console.addFilter(console_filter)
+        if filename:
+            logging.basicConfig(level=debug_level,
+                    format='%(asctime)s %(filename)s[line:%(lineno)d] %(levelname)s %(message)s',
+                    datefmt='%a, %d %b %Y %H:%M:%S',
+                    filename=filename,
+                    filemode='w',
+                    )
+        else:
+            logging.basicConfig(level=debug_level,
+                    format='%(asctime)s %(filename)s[line:%(lineno)d] %(levelname)s %(message)s',
+                    datefmt='%a, %d %b %Y %H:%M:%S',
+                    handlers = [console,]
+                    )
+
+    @staticmethod
+    def get_arguments(arg_dict:dict)->dict:
+        '''
+        command line argment define and get value
+
+        Args:
+            arg_dict (dict): the argment define .
+                             {argname1:{"short":"","long":"","default":"","help":"","type":"str|bool"},
+                             argname2:{"short":"","long":"","default":"","help":""}}
+
+        Returns:
+            dict: the commandline arg value s {argname:value,argname:value}
+        '''
+        parser = argparse.ArgumentParser(
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter )
+        for argname,arginfo in arg_dict.items():
+            
+            action_type="store_true" if arginfo.get("type","str")=="bool" else None
+            if arginfo.get("short",""):
+                parser.add_argument(arginfo.get("short",""),arginfo.get("long","--"+argname),
+                        help=arginfo.get("help",argname),default=arginfo.get("default",None),action=action_type)
+            else:
+                parser.add_argument(arginfo.get("long","--"+argname),
+                        help=arginfo.get("help",argname),default=arginfo.get("default",None),action=action_type)
+        argvalues =  parser.parse_args()
+        value_dict = {}
+        for argname in arg_dict.keys():
+            value_dict[argname] =  getattr(argvalues,argname,None)
+
+        return value_dict
+
+    @staticmethod
+    def parser_argument()->argparse.ArgumentParser:
+        '''
+        deprecated , please use Tools.get_arguments() instead!
+
+        Returns:
+            argparse.ArgumentParser: argparse.ArgumentParser
+        '''
         parser = argparse.ArgumentParser(
             formatter_class=argparse.ArgumentDefaultsHelpFormatter )
         parser.add_argument('-d', '--debug', action='store_true',
@@ -159,7 +225,7 @@ class Tools(object):
                             default=False,
                             help='daemon mode' )
         parser.add_argument('-o','--org_id',
-                            default="misas",
+                            default="org",
                             help='org id' )
         parser.add_argument('-n','--node_id',
                             default="",
@@ -195,30 +261,6 @@ class Tools(object):
         parser.add_argument('--version', action='version', version= "1.0")
         return parser
 
-
-    # @staticmethod
-    # def run_daemon(config:dict,status:dict,flag:str):
-    #     '''
-    #     run adminserver with config, until status[falg]=True
-
-    #     Args:
-    #         config (_type_): {admin_port:9001,admin_pass:password,allow_src:127.0.0.1,admin_process:None}}
-    #         status (_type_): _description_
-    #         flag (_type_): _description_
-    #     '''
-    #     adminserver = AdminServer(port=config.get("admin_port", 9000),
-    #                                 prompt= config.get("prompt","Admin"),
-    #                                 admin_pass =config["admin_pass"],
-    #                                 admin_process=config["admin_process"])
-    #     adminserver.start()
-
-    #     while not status.get(flag,False):
-    #         time.sleep(1)
-    #         pass
-    #     adminserver.quit()
-    #     status[flag] = True
-    #     return 
-
     @staticmethod
     def run_interactive(prompt,command_handle):
         command = "help"
